@@ -6,9 +6,11 @@ module Stackctl.AWS.Core
   , awsSend
   , awsPaginate
   , awsAwait
+  , awsAssumeRole
 
   -- * Modifiers on 'AwsEnv'
   , awsWithin
+  , awsTimeout
 
   -- * 'Amazonka' extensions
   , AccountId(..)
@@ -20,10 +22,12 @@ module Stackctl.AWS.Core
   , MonadResource
   ) where
 
-import Stackctl.Prelude
+import Stackctl.Prelude hiding (timeout)
 
 import Amazonka hiding (LogLevel(..))
 import qualified Amazonka as AWS
+import Amazonka.Auth.Keys (fromSession)
+import Amazonka.STS.AssumeRole
 import Conduit (ConduitM)
 import Control.Monad.Logger (defaultLoc, toLogStr)
 import Control.Monad.Trans.Resource (MonadResource)
@@ -103,9 +107,36 @@ awsAwait w req = do
   AwsEnv env <- view awsEnvL
   await env w req
 
+awsAssumeRole
+  :: (MonadResource m, MonadReader env m, HasAwsEnv env)
+  => Text
+  -- ^ Role ARN
+  -> Text
+  -- ^ Session name
+  -> m a
+  -- ^ Action to run as the assumed role
+  -> m a
+awsAssumeRole role sessionName f = do
+  let req = newAssumeRole role sessionName
+
+  assumeEnv <- awsSimple "sts:AssumeRole" req $ \resp -> do
+    creds <- resp ^. assumeRoleResponse_credentials
+    token <- creds ^. authSessionToken
+
+    let
+      accessKeyId = creds ^. authAccessKeyId
+      secretAccessKey = creds ^. authSecretAccessKey
+
+    pure $ fromSession accessKeyId secretAccessKey token
+
+  local (awsEnvL . unL %~ assumeEnv) f
+
 awsWithin :: (MonadReader env m, HasAwsEnv env) => Region -> m a -> m a
 awsWithin r = local $ over (awsEnvL . unL) (within r)
 
+awsTimeout :: (MonadReader env m, HasAwsEnv env) => Seconds -> m a -> m a
+awsTimeout t = local $ over (awsEnvL . unL) (timeout t)
+
 newtype AccountId = AccountId
   { unAccountId :: Text
   }
