@@ -6,6 +6,7 @@ import Stackctl.Prelude
 
 import Stackctl.AWS
 import Stackctl.AWS.Scope
+import Stackctl.Config (emptyConfig)
 import Stackctl.StackSpec
 import Stackctl.StackSpecPath
 import Stackctl.StackSpecYaml
@@ -27,12 +28,14 @@ spec = do
         `shouldBe` ["iam", "roles", "networking", "app"]
 
 toSpec :: Text -> [Text] -> StackSpec
-toSpec name depends = buildStackSpec "." specPath specBody
+toSpec name depends = flip runReader emptyConfig
+  $ buildStackSpec "." specPath specBody
  where
   stackName = StackName name
   specPath = stackSpecPath scope stackName "a/b.yaml"
   specBody = StackSpecYaml
-    { ssyDepends = Just $ map StackName depends
+    { ssyDescription = Nothing
+    , ssyDepends = Just $ map StackName depends
     , ssyActions = Nothing
     , ssyTemplate = ""
     , ssyParameters = Nothing
